=== modified file 'lib/fileservice_lib/action.py'
--- lib/fileservice_lib/action.py	2008-07-21 04:56:00 +0000
+++ lib/fileservice_lib/action.py	2008-07-21 06:26:27 +0000
@@ -256,8 +256,7 @@
 
 ### ACTIONS ###
 
-def action_remove(req, fields):
-    # TODO: Do an SVN rm if the file is versioned.
+def action_delete(req, fields):
     # TODO: Disallow removal of student's home directory
     """Removes a list of files or directories.
 
@@ -541,6 +540,19 @@
     except pysvn.ClientError, e:
         raise ActionError(str(e))
 
+def action_svnremove(req, fields):
+    """Performs a "svn remove" on each file specified.
+
+    Reads fields: 'path' (multiple)
+    """
+    paths = fields.getlist('path')
+    paths = map(lambda path: actionpath_to_local(req, path), paths)
+
+    try:
+        svnclient.remove(paths, force=True)
+    except pysvn.ClientError, e:
+        raise ActionError(str(e))
+
 def action_svnupdate(req, fields):
     """Performs a "svn update" to each file specified.
 
@@ -659,7 +671,7 @@
 # Each function has the interface f(req, fields).
 
 actions_table = {
-    "remove" : action_remove,
+    "delete" : action_delete,
     "move" : action_move,
     "mkdir" : action_mkdir,
     "putfile" : action_putfile,
@@ -669,6 +681,7 @@
     "unpublish" : action_unpublish,
 
     "svnadd" : action_svnadd,
+    "svnremove" : action_svnremove,
     "svnupdate" : action_svnupdate,
     "svnresolved" : action_svnresolved,
     "svnrevert" : action_svnrevert,

=== modified file 'www/apps/browser/__init__.py'
--- www/apps/browser/__init__.py	2008-07-21 04:56:00 +0000
+++ www/apps/browser/__init__.py	2008-07-21 06:26:27 +0000
@@ -174,6 +174,7 @@
       ]),
       ('Subversion', True, [
         ('svnadd',      ['Add',          'Schedule the selected temporary files to be added permanently']),
+        ('svnremove',   ['Remove',       'Schedule the selected permanent files to be removed']),
         ('svndiff',     ['Diff',         'View any changes to the selected file since its last committed state']),
         ('svnrevert',   ['Revert',       'Restore the selected files back to their last committed state']),
         ('svnupdate',   ['Update',       'Update your files with changes from the permanent repository']),

=== modified file 'www/media/browser/browser.js'
--- www/media/browser/browser.js	2008-07-21 04:56:00 +0000
+++ www/media/browser/browser.js	2008-07-21 06:26:27 +0000
@@ -732,7 +732,7 @@
     /* Subversion actions */
     /* These are only useful if we are in a versioned directory and have some
      * files selected. */
-    set_action_state(["svnadd", "svnrevert", "svncommit"], numsel >= 1 && current_file.svnstatus);
+    set_action_state(["svnadd", "svnremove", "svnrevert", "svncommit"], numsel >= 1 && current_file.svnstatus);
 
     /* Diff, log and update only support one path at the moment, so we must
      * have 0 or 1 versioned files selected. If 0, the directory must be
@@ -818,7 +818,7 @@
         action_rename(filename);
         break;
     case "delete":
-        action_remove(selected_files);
+        action_delete(selected_files);
         break;
     case "copy":
         action_copy(selected_files);
@@ -841,6 +841,9 @@
     case "svnadd":
         action_add(selected_files);
         break;
+    case "svnremove":
+        action_remove(selected_files);
+        break;
     case "svnrevert":
         action_revert(selected_files);
         break;

=== modified file 'www/media/browser/listing.js'
--- www/media/browser/listing.js	2008-07-21 04:56:00 +0000
+++ www/media/browser/listing.js	2008-07-21 06:26:27 +0000
@@ -50,7 +50,7 @@
     return false;
 }
 
-function action_remove(files)
+function action_delete(files)
 {
     var conf_msg;
     /* A heavy nesty bit of logic to determine the confirmation message.
@@ -97,7 +97,7 @@
 
     var confirmed = confirm(conf_msg);
     if (!confirmed) return;
-    do_action("remove", current_path, {"path":files});
+    do_action("delete", current_path, {"path":files});
     return false;
 }
 
@@ -163,6 +163,12 @@
     return false;
 }
 
+function action_remove(files)
+{
+    do_action("svnremove", current_path, {"path":files});
+    return false;
+}
+
 function action_revert(files)
 {
     do_action("svnrevert", current_path, {"path":files});

